@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/glite/org.glite.lb.server/src/bkserverd.c,v 1.153 2012/12/13 13:21:53 valtri Exp $"
+#ident "$Header$"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -144,6 +144,7 @@ static int				noAuth = 0;
 static int				noIndex = 0;
 static int				strict_locking = 0;
 static int 				greyjobs = 0;
+static int                              async_registrations = 0;
 static int 				count_statistics = 1;
 static int 				count_server_stats = 1;
 static char 				*stats_file_prefix = NULL;
@@ -231,6 +232,7 @@ static struct option opts[] = {
 #endif
 	{"transactions",	1,	NULL,	'b'},
 	{"greyjobs",	0,	NULL,	'g'},
+	{"async-registrations", 0, NULL, 'Q'},
 	{"withproxy",	0,	NULL,	'B'},
 	{"proxyonly",	0,	NULL,	'P'},
 	{"sock",	1,	NULL,	'o'},
@@ -245,7 +247,7 @@ static struct option opts[] = {
 	{NULL,0,NULL,0}
 };
 
-static const char *get_opt_string = "Ac:k:C:V:p:a:drm:M:ns:i:S:D:J:jR:F:xOL:N:X:Y:T:t:e:f:zb:gPBo:q:W:Z:GI:l:EH:"
+static const char *get_opt_string = "Ac:k:C:V:p:a:drm:M:ns:i:S:D:J:jR:F:xOL:N:X:Y:T:t:e:f:zb:gQPBo:q:W:Z:GI:l:EH:"
 #ifdef GLITE_LB_SERVER_WITH_WS
 	"w:"
 #endif
@@ -298,6 +300,7 @@ static void usage(char *me)
 		"\t-K, --perf-sink\t where to sink events\n"
 #endif
 		"\t-g,--greyjobs\t allow delayed registration (grey jobs), implies --strict-locking\n"
+		"\t-Q,--async-registrations\t allow asynchronous registrations (weaker form of grey jobs) \n"
 		"\t-P,--proxyonly\t	run only proxy service\n"
 		"\t-B,--withproxy\t	run both server and proxy service\n"
 		"\t-o,--sock\t path-name to the local socket for communication with LB proxy\n"
@@ -508,8 +511,10 @@ int main(int argc, char *argv[])
 		case 'K': sink_mode = atoi(optarg);
 			  break;
 #endif
-		case 'g': greyjobs = strict_locking = 1;
+		case 'g': greyjobs = strict_locking = 1; 
 			  break;
+	        case 'Q': async_registrations = 1; /* XXX should set strict locking too? */
+		          break;
 		case 'P': mode = SERVICE_PROXY;
 			  break;
 		case 'B': mode = SERVICE_PROXY_SERVER;
@@ -1119,10 +1124,12 @@ int bk_handle_connection(int conn, struct timeval *timeout, void *data)
 	else ctx->html_header_file = NULL;
 
 	ctx->id_mapping.num = id_mapping.num;
-	ctx->id_mapping.rules = (_edg_wll_mapping_rule*)malloc(ctx->id_mapping.num * sizeof(_edg_wll_mapping_rule));
-	for ( i = 0; i < ctx->id_mapping.num; i++ ) {
-		ctx->id_mapping.rules[i].a = strdup(id_mapping.rules[i].a);
-		ctx->id_mapping.rules[i].b = strdup(id_mapping.rules[i].b);
+	if (id_mapping.num) {
+		ctx->id_mapping.rules = (_edg_wll_mapping_rule*)malloc(ctx->id_mapping.num * sizeof(_edg_wll_mapping_rule));
+		for ( i = 0; i < ctx->id_mapping.num; i++ ) {
+			ctx->id_mapping.rules[i].a = strdup(id_mapping.rules[i].a);
+			ctx->id_mapping.rules[i].b = strdup(id_mapping.rules[i].b);
+		}
 	}
 
 	gettimeofday(&conn_start, 0);
@@ -1289,6 +1296,7 @@ int bk_handle_connection(int conn, struct timeval *timeout, void *data)
 	}
 	ctx->strict_locking = strict_locking;
 	ctx->greyjobs = greyjobs;
+	ctx->async_registrations = async_registrations;
 	ctx->exclusive_zombies = exclusive_zombies;
 
 	for (totpref = 0; msg_prefixes[totpref]; totpref++);
@@ -1415,6 +1423,8 @@ int bk_handle_connection_proxy(int conn, struct timeval *timeout, void *data)
 					&authz_policy.actions[i].rules[j]);
 	}
 
+	memcpy(ctx->purge_timeout, purge_timeout, sizeof(ctx->purge_timeout));
+
 	/* required to match superuser-authorized notifications */
 
 	if (fake_host)
@@ -1599,7 +1609,19 @@ int bk_accept_serve(int conn, struct timeval *timeout, void *cdata)
 	gettimeofday(&before, NULL);
 	err = edg_wll_AcceptHTTP(ctx, &body, &resp, &hdrOut, &bodyOut, &httpErr);
 	if (err && (err = handle_server_error(ctx))){
-		edg_wll_DoneHTTP(ctx, resp, hdrOut, bodyOut);
+		switch (err) {
+			case EIO:
+				glite_common_log(LOG_CATEGORY_LB_SERVER_REQUEST, LOG_PRIORITY_INFO, "I/O error on answer to client '%s'", ctx->connections->serverConnection->peerName);
+				break;
+			case ECONNREFUSED:
+				glite_common_log(LOG_CATEGORY_LB_SERVER_REQUEST, LOG_PRIORITY_INFO, "Connection refused on answer to client '%s'", ctx->connections->serverConnection->peerName);
+				break;
+			case ENOTCONN:
+				glite_common_log(LOG_CATEGORY_LB_SERVER_REQUEST, LOG_PRIORITY_INFO, "Client '%s' closed connection", ctx->connections->serverConnection->peerName);
+				break;
+			default:
+				edg_wll_DoneHTTP(ctx, resp, hdrOut, bodyOut);
+		}
 	        free(resp);
 	        free(bodyOut);
                 if (body)
