@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/glite/org.glite.lb.server/src/lb_html.c,v 1.66 2012/09/10 08:45:46 zsustr Exp $"
+#ident "$Header$"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -144,6 +144,7 @@ int edg_wll_ConfigurationToHTML(edg_wll_Context ctx, int admin, char **message,
 	add_row(&out, "server_version", "Server version", VERSION, NULL, text);
 
 	add_row(&out, "server_identity", "Server identity", ctx->serverIdentity, NULL, text);
+	add_row(&out, "client_identity", "Client identity", ctx->peerName, NULL, text);
 
 	for (i = 0; ctx->job_index && ctx->job_index[i]; i++){
 		char *idx_title = edg_wll_QueryRecToColumn(ctx->job_index[i]);
@@ -235,6 +236,7 @@ int edg_wll_ConfigurationToHTML(edg_wll_Context ctx, int admin, char **message,
 		if (a) add_row(&out, "id_mapping", "ID Mapping", a, NULL, text);
 		free(a);
 
+		add_row(&out, "usability", "Usability", "Improved", NULL, text);
         }
 
         if (!text) {
@@ -553,7 +555,10 @@ int edg_wll_GeneralJobStatusToHTML(edg_wll_Context ctx UNUSED_VAR, edg_wll_JobSt
 			chtemp = edg_wlc_JobIdUnparse(stat.ft_compute_job);
 			add_row(&out, "compute_job", "Compute job", chtemp, NULL, text);
 			free(chtemp);
-			add_row(&out, "sandbox_type", "Sandbox type", edg_wll_StatusFt_sandbox_typeNames[stat.ft_sandbox_type], NULL, text);
+
+			if (stat.ft_sandbox_type < EDG_WLL_NUMBER_OF_FT_SANDBOX_TYPES && stat.ft_sandbox_type != (enum edg_wll_StatFt_sandbox_type)-1) i = stat.ft_sandbox_type;
+			else i = -1;
+			add_row(&out, "sandbox_type", "Sandbox type", i != -1 ? edg_wll_StatusFt_sandbox_typeNames[i] : NULL, NULL, text);
 			add_row(&out, "ft_source", "File transfer source", stat.ft_src, NULL, text);
 			add_row(&out, "ft_destination", "File transfer destination", stat.ft_dest, NULL, text);
 			break;
