@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/glite/org.glite.lb.server/src/notif_match.c,v 1.41 2012/08/23 11:30:14 zsustr Exp $"
+#ident "$Header$"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -113,6 +113,8 @@ int edg_wll_NotifMatch(edg_wll_Context ctx, const edg_wll_JobStat *oldstat, cons
 		ju = edg_wlc_JobIdGetUnique(stat->jobId),NOTIF_ALL_JOBS,cond_where ? cond_where : "",cond_and_where ? cond_and_where : "");
 
 	free(ju); ju = NULL;
+	free(cond_where); cond_where = NULL;
+	free(cond_and_where); cond_and_where = NULL;
 	glite_common_log_msg(LOG_CATEGORY_LB_SERVER_DB, LOG_PRIORITY_DEBUG, jobq);
 
 	if (edg_wll_ExecSQL(ctx,jobq,&jobs) < 0) goto err;
@@ -140,7 +142,6 @@ int edg_wll_NotifMatch(edg_wll_Context ctx, const edg_wll_JobStat *oldstat, cons
                                 		 getpid(),
                 		                 ju = glite_jobid_getUnique(newstat.jobId));
 		                free(ju);
-		                edg_wll_SetError(ctx, EPERM, NULL);
 				for (i=0; i<sizeof(jobc)/sizeof(jobc[0]); i++) free(jobc[i]);
 				continue;
         		}
@@ -217,6 +218,8 @@ err:
 	if ( nid ) edg_wll_NotifIdFree(nid);
 	free(jobq);
 	glite_lbu_FreeStmt(&jobs);
+	free(cond_where);
+	free(cond_and_where);
 	return edg_wll_Error(ctx,NULL,NULL);
 }
 
