@@ -44,6 +44,7 @@ limitations under the License.
 #define LASTUPDATETIME	lbt__queryAttr__LASTUPDATETIME
 #define NETWORKSERVER	lbt__queryAttr__NETWORKSERVER
 #define JOBTYPE		lbt__queryAttr__JOBTYPE
+#define VM_STATUS       lbt__queryAttr__VM_USCORESTATUS
 
 #define EQUAL		lbt__queryOp__EQUAL
 #define UNEQUAL		lbt__queryOp__UNEQUAL
@@ -93,6 +94,9 @@ limitations under the License.
 #define PBSsMom		lbt__eventSource__PBSsMom
 #define PBSMom		lbt__eventSource__PBSMom
 #define PBSScheduler	lbt__eventSource__PBSScheduler
+#define CloudManager	lbt__eventSource__CloudManager
+#define VMManager	lbt__eventSource__VMManager
+#define VMSystem	lbt__eventSource__VMSystem
 
 #endif
 
